@@ -88,7 +88,7 @@ class EncDecSpeakerLabelModel(ModelPT, ExportableEncDecModel):
     def __init__(self, cfg: DictConfig, trainer: Trainer = None):
         self.world_size = 1
         if trainer is not None:
-            self.world_size = trainer.num_nodes * trainer.num_gpus
+            self.world_size = trainer.num_nodes * trainer.num_devices
 
         super().__init__(cfg=cfg, trainer=trainer)
 
