@@ -62,21 +62,11 @@ class ConvASREncoder(NeuralModule, Exportable):
 
     def _prepare_for_export(self, **kwargs):
         m_count = 0
-        stride = 1
-        one_hour = 100 * 60 * 60 * 1  # 1 sec / 0.01 window stride = 100 frames / second * 60 sec * 60 min * 1 hour
-
         for name, m in self.named_modules():
             if isinstance(m, MaskedConv1d):
                 m.use_mask = False
                 m_count += 1
 
-            if isinstance(m, MaskedConv1d):
-                if m.conv.stride[0] > 1 and 'mconv' in name:
-                    stride = stride * m.conv.stride[0]
-
-            if isinstance(m, SqueezeExcite):
-                m.set_max_len(int(one_hour // stride))  # One hour divided by current stride level
-
         Exportable._prepare_for_export(self, **kwargs)
         logging.warning(f"Turned off {m_count} masked convolutions")
 
@@ -196,7 +186,7 @@ class ConvASREncoder(NeuralModule, Exportable):
         self.encoder = torch.nn.Sequential(*encoder_layers)
         self.apply(lambda x: init_weights(x, mode=init_mode))
 
-        self.max_audio_length = torch.tensor(0, dtype=torch.int32)
+        self.max_audio_length = 0
 
     @typecheck()
     def forward(self, audio_signal, length):
@@ -218,16 +208,25 @@ class ConvASREncoder(NeuralModule, Exportable):
             seq_length = global_max_len.int().item()
 
         if seq_length > self.max_audio_length:
-            self.max_audio_length = seq_length * 2
+            if seq_length < 5000:
+                seq_length = seq_length * 2
+            elif seq_length < 10000:
+                seq_length = seq_length * 1.5
+            self.max_audio_length = seq_length
+
+            device = next(self.parameters()).device
+            seq_range = torch.arange(0, self.max_audio_length, device=device)
+            if hasattr(self, 'seq_range'):
+                self.seq_range = seq_range
+            else:
+                self.register_buffer('seq_range', seq_range, persistent=False)
 
             # Update all submodules
             for name, m in self.named_modules():
                 if isinstance(m, MaskedConv1d):
-                    if m.use_mask:
-                        m.update_masked_length(self.max_audio_length, device=device)
-
-                if isinstance(m, SqueezeExcite):
-                    m.set_max_len(self.max_audio_length)
+                    m.update_masked_length(self.max_audio_length, seq_range=self.seq_range)
+                elif isinstance(m, SqueezeExcite):
+                    m.set_max_len(self.max_audio_length, seq_range=self.seq_range)
 
 
 class ParallelConvASREncoder(NeuralModule, Exportable):
@@ -241,10 +240,6 @@ class ParallelConvASREncoder(NeuralModule, Exportable):
             if isinstance(m, MaskedConv1d):
                 m.use_mask = False
                 m_count += 1
-
-            if isinstance(m, SqueezeExcite):
-                m.set_max_len(8192)
-
         logging.warning(f"Turned off {m_count} masked convolutions")
 
     def input_example(self, max_batch=1, max_dim=256):
@@ -494,16 +489,16 @@ class ConvASRDecoderReconstruction(NeuralModule, Exportable):
         feat_out,
         feat_hidden,
         stride_layers,
+        non_stride_layers=0,
         kernel_size=11,
         init_mode="xavier_uniform",
         activation="relu",
+        stride_transpose=True,
     ):
         super().__init__()
 
-        if stride_layers > 0 and (kernel_size < 3 or kernel_size % 2 == 0):
-            raise ValueError(
-                "Kernel size in this decoder needs to be >= 3 and odd when using at least 1 stride layer."
-            )
+        if ((stride_layers + non_stride_layers) > 0) and (kernel_size < 3 or kernel_size % 2 == 0):
+            raise ValueError("Kernel size in this decoder needs to be >= 3 and odd when using at least 1 conv layer.")
 
         activation = jasper_activations[activation]()
 
@@ -513,16 +508,44 @@ class ConvASRDecoderReconstruction(NeuralModule, Exportable):
 
         self.decoder_layers = [nn.Conv1d(self.feat_in, self.feat_hidden, kernel_size=1, bias=True)]
         for i in range(stride_layers):
+            self.decoder_layers.append(activation)
+            if stride_transpose:
+                self.decoder_layers.append(
+                    nn.ConvTranspose1d(
+                        self.feat_hidden,
+                        self.feat_hidden,
+                        kernel_size,
+                        stride=2,
+                        padding=(kernel_size - 3) // 2 + 1,
+                        output_padding=1,
+                        bias=True,
+                        groups=self.feat_hidden,
+                    )
+                )
+            else:
+                self.decoder_layers.append(
+                    nn.Conv1d(
+                        self.feat_hidden,
+                        self.feat_hidden,
+                        kernel_size,
+                        stride=2,
+                        padding=(kernel_size - 1) // 2,
+                        bias=True,
+                        groups=self.feat_hidden,
+                    )
+                )
+            self.decoder_layers.append(nn.Conv1d(self.feat_hidden, self.feat_hidden, kernel_size=1, bias=True))
+            self.decoder_layers.append(nn.BatchNorm1d(self.feat_hidden, eps=1e-3, momentum=0.1))
+        for i in range(non_stride_layers):
             self.decoder_layers.append(activation)
             self.decoder_layers.append(
-                nn.ConvTranspose1d(
+                nn.Conv1d(
                     self.feat_hidden,
                     self.feat_hidden,
                     kernel_size,
-                    stride=2,
-                    padding=(kernel_size - 3) // 2 + 1,
-                    output_padding=1,
                     bias=True,
+                    groups=self.feat_hidden,
+                    padding=kernel_size // 2,
                 )
             )
             self.decoder_layers.append(nn.Conv1d(self.feat_hidden, self.feat_hidden, kernel_size=1, bias=True))
