@@ -414,7 +414,7 @@ class TarredTranslationDataset(IterableDataset):
         self._dataset = wd.WebDataset(urls=text_tar_filepaths, nodesplitter=None)
 
         if shuffle_n > 0:
-            self._dataset = self._dataset.shuffle(shuffle_n)
+            self._dataset = self._dataset.shuffle(shuffle_n, initial=shuffle_n)
         else:
             logging.info("WebDataset will not shuffle files within the tar files.")
 
