@@ -53,15 +53,40 @@ class MegatronModule(torch.nn.Module):
         self.share_word_embeddings = share_word_embeddings
 
     def word_embeddings_weight(self):
-        if parallel_state.is_pipeline_first_stage(ignore_virtual=True):
-            return self.language_model.embedding.word_embeddings.weight
-        if parallel_state.is_pipeline_last_stage(ignore_virtual=True):
+        if self.pre_process:
+            if hasattr(self, 'language_model'):
+                return self.language_model.embedding.word_embeddings.weight
+            elif hasattr(self, 'encoder_embedding'):
+                return self.encoder_embedding.word_embeddings.weight
+            elif hasattr(self, 'decoder_embedding'):
+                return self.decoder_embedding.word_embeddings.weight
+            else:
+                raise ValueError(
+                    f"Pre_process is True, but no embedding is found on this rank. Looked for language_model.embedding, encoder_embedding, and decoder_embedding"
+                )
+        else:
+            # This is the pipeline parallel last stage.
             if not self.share_word_embeddings:
                 raise Exception(
                     'word_embeddings_weight() called for last ' 'stage, but share_word_embeddings is false'
                 )
             return self.word_embeddings.weight
-        raise Exception('word_embeddings_weight() should be ' 'called for first and last stage only')
+
+    def position_embeddings_weight(self):
+        if self.pre_process:
+            if hasattr(self, 'language_model'):
+                return self.language_model.embedding.position_embeddings.weight
+            elif hasattr(self, 'encoder_embedding'):
+                return self.encoder_embedding.position_embeddings.weight
+            elif hasattr(self, 'decoder_embedding'):
+                return self.decoder_embedding.position_embeddings.weight
+            else:
+                raise ValueError(
+                    f"Pre_process is True, but no embedding is found on this rank. Looked for language_model.embedding, encoder_embedding, and decoder_embedding"
+                )
+        else:
+            # We only need position embeddings on the encoder and decoder first stages where pre_process=True
+            raise ValueError(f"Pre_process is False, there is no position embedding on this rank.")
 
     def initialize_word_embeddings(self, init_method, vocab_size, hidden_size):
         if not self.share_word_embeddings:
@@ -85,7 +110,8 @@ class MegatronModule(torch.nn.Module):
         # 3. In the training loop, before an all-reduce between the grads of
         #    the two word_embeddings layers to ensure that every applied weight
         #    update is the same on both stages.
-        if parallel_state.is_pipeline_last_stage():
+        if parallel_state.is_pipeline_last_stage() and not self.pre_process:
+            # This is relevant for T5 when the decoder is only on a single rank. It is the last stage of the pipeline and also has embeddings on this rank already.
             assert not parallel_state.is_pipeline_first_stage()
             self._word_embeddings_for_head_key = 'word_embeddings_for_head'
             # set word_embeddings weights to 0 here, then copy first
@@ -96,10 +122,22 @@ class MegatronModule(torch.nn.Module):
             self.word_embeddings.weight.data.fill_(0)
             self.word_embeddings.weight.shared = True
 
+        # Zero out initial weights for decoder embedding.
+        # NOTE: We don't currently support T5 with the interleaved schedule.
+        # This is the case where PP > 1 and we're on the decoder first stage.
+        if not parallel_state.is_pipeline_first_stage(ignore_virtual=True) and self.pre_process:
+            if hasattr(self, 'language_model'):
+                # Zero params for GPT
+                self.language_model.embedding.zero_parameters()
+            else:
+                # Zero decoder embeddings for T5
+                assert hasattr(self, 'decoder_embedding')
+                self.decoder_embedding.zero_parameters()
+
     def sync_initial_word_embeddings(self):
 
         if torch.distributed.is_initialized():
-            if parallel_state.is_pipeline_first_stage() or parallel_state.is_pipeline_last_stage():
+            if parallel_state.is_rank_in_embedding_group():
                 torch.distributed.all_reduce(
                     self.word_embeddings_weight().data, group=parallel_state.get_embedding_group()
                 )
@@ -112,6 +150,19 @@ class MegatronModule(torch.nn.Module):
                 "something is definitely wrong."
             )
 
+    def sync_initial_position_embeddings(self):
+        # Ensure that the encoder first stage and decoder first have the same
+        # initial position embedding parameter values.
+        # NOTE: We don't currently support T5 with the interleaved schedule.
+        if (
+            parallel_state.is_rank_in_position_embedding_group()
+            and parallel_state.get_pipeline_model_parallel_split_rank() is not None
+        ):
+            # TODO: Support tokentype embedding.
+            # self.language_model.embedding.cuda()
+            position_embeddings = self.position_embeddings_weight()
+            torch.distributed.all_reduce(position_embeddings.data, group=parallel_state.get_position_embedding_group())
+
 
 def conversion_helper(val, conversion):
     """Apply conversion to val. Recursively apply conversion if `val`
@@ -185,7 +236,8 @@ class Float16Module(MegatronModule):
         return self.module.set_input_tensor(input_tensor)
 
     def forward(self, *inputs, **kwargs):
-        if parallel_state.is_pipeline_first_stage():
+        # Note: Legacy checkpoints didn't have pre-process.
+        if getattr(self.module, 'pre_process', True):
             inputs = fp32_to_float16(inputs, self.float16_converter)
         outputs = self.module(*inputs, **kwargs)
         if parallel_state.is_pipeline_last_stage():
@@ -199,12 +251,37 @@ class Float16Module(MegatronModule):
         return self.module.state_dict_for_save_checkpoint(destination, prefix, keep_vars)
 
     def word_embeddings_weight(self):
-        if parallel_state.is_pipeline_first_stage(ignore_virtual=True):
-            return self.module.language_model.embedding.word_embeddings.weight
-        if parallel_state.is_pipeline_last_stage(ignore_virtual=True):
+        if self.module.pre_process:
+            if hasattr(self.module, 'language_model'):
+                return self.module.language_model.embedding.word_embeddings.weight
+            elif hasattr(self.module, 'encoder_embedding'):
+                return self.module.encoder_embedding.word_embeddings.weight
+            elif hasattr(self.module, 'decoder_embedding'):
+                return self.module.decoder_embedding.word_embeddings.weight
+            else:
+                raise ValueError(
+                    f"Pre_process is True, but no embedding is found on this rank. Looked for language_model.embedding, encoder_embedding, and decoder_embedding"
+                )
+        else:
+            # This is the pipeline parallel last stage.
             if not self.share_word_embeddings:
                 raise Exception(
                     'word_embeddings_weight() called for last ' 'stage, but share_word_embeddings is false'
                 )
             return self.module.word_embeddings.weight
-        raise Exception('word_embeddings_weight() should be ' 'called for first and last stage only')
+
+    def position_embeddings_weight(self):
+        if self.module.pre_process:
+            if hasattr(self.module, 'language_model'):
+                return self.module.language_model.embedding.position_embeddings.weight
+            elif hasattr(self.module, 'encoder_embedding'):
+                return self.module.encoder_embedding.position_embeddings.weight
+            elif hasattr(self.module, 'decoder_embedding'):
+                return self.module.decoder_embedding.position_embeddings.weight
+            else:
+                raise ValueError(
+                    f"Pre_process is True, but no embedding is found on this rank. Looked for language_model.position_embeddings, encoder_embedding.position_embedding_weight, and decoder_embedding.position_embedding_weight"
+                )
+        else:
+            # We only need position embeddings on the encoder and decoder first stages where pre_process=True
+            raise ValueError(f"Pre_process is False, there is no position embedding on this rank.")
