@@ -23,13 +23,14 @@ try:
     from nemo.collections.tts.models.glow_tts import GlowTTSModel
     from nemo.collections.tts.models.hifigan import HifiGanModel
     from nemo.collections.tts.models.melgan import MelGanModel
+    from nemo.collections.tts.models.mixer_tts import MixerTTSModel
     from nemo.collections.tts.models.squeezewave import SqueezeWaveModel
     from nemo.collections.tts.models.tacotron2 import Tacotron2Model
     from nemo.collections.tts.models.talknet import TalkNetDursModel, TalkNetPitchModel, TalkNetSpectModel
     from nemo.collections.tts.models.two_stages import GriffinLimModel, MelPsuedoInverseModel, TwoStagesModel
     from nemo.collections.tts.models.uniglow import UniGlowModel
+    from nemo.collections.tts.models.univnet import UnivNetModel
     from nemo.collections.tts.models.waveglow import WaveGlowModel
-    from nemo.collections.tts.models.mixer_tts import MixerTTSModel
 except ModuleNotFoundError:
     pass
 
@@ -55,4 +56,5 @@ __all__ = [
     "FastSpeech2HifiGanE2EModel",
     "AlignerModel",
     "MixerTTSModel",
+    "UnivNetModel",
 ]
