@@ -42,7 +42,6 @@ class TrainerConfig:
     gradient_clip_val: float = 0
     process_position: int = 0
     num_nodes: int = 1
-    num_processes: int = 1
     gpus: Optional[Any] = None
     auto_select_gpus: bool = False
     tpu_cores: Optional[Any] = None
@@ -74,7 +73,6 @@ class TrainerConfig:
     profiler: Optional[Any] = None
     benchmark: bool = False
     deterministic: bool = False
-    reload_dataloaders_every_epoch: bool = False
     auto_lr_find: Any = False
     replace_sampler_ddp: bool = True
     detect_anomaly: bool = False
