@@ -238,3 +238,19 @@ def pre_process(text: str) -> str:
     # remove extra space
     text = re.sub(r' +', ' ', text)
     return text
+
+
+def check_installation():
+    try:
+        import pynini
+
+        PYNINI_AVAILABLE = True
+
+    except (ModuleNotFoundError, ImportError):
+        PYNINI_AVAILABLE = False
+    return PYNINI_AVAILABLE
+
+
+def get_installation_msg():
+    msg = "`pynini` is not installed ! \n Please run the `nemo_text_processing/setup.sh` script prior to usage of this toolkit."
+    return msg
