@@ -67,10 +67,6 @@ class DecimalFst(GraphFst):
             | (self.optional_integer + self.fractional + self.optional_quantity)
         )
 
-        # 1.35 -> one thirty five (without "point")
-        if not deterministic:
-            graph |= self.integer + delete_space + insert_space + self.fractional_default + self.optional_quantity
-
         self.numbers = graph
         delete_tokens = self.delete_tokens(graph)
         self.fst = delete_tokens.optimize()
